==> haskell-aws-0.24-150-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aws
version:              0.24
visibility:           public
id:                   aws-0.24-ArK6FCBJgus76Is8AH6EnZ
key:                  aws-0.24-ArK6FCBJgus76Is8AH6EnZ
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  233247eb2758f6f5439a6d438558232d
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-9.2.8/site-local/aws-0.24
library-dirs:         /usr/lib/ghc-9.2.8/site-local/aws-0.24
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aws
hs-libraries:         HSaws-0.24-ArK6FCBJgus76Is8AH6EnZ
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    base16-bytestring-1.0.2.0-1EKQKfIbtqrKykCu8OdSyV
    base64-bytestring-1.2.1.0-DECs32jOMrhU6x3ypSYAj
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    byteable-0.1.1-2aVcTelA6XA9YKIvhjRaxC bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    conduit-extra-1.3.6-GQSgUNMr0ZN9ENRzkRi4eD containers-0.6.5.1
    cryptonite-0.30-7YCFiEak3iS4jVbhqnIKep
    data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9 directory-1.3.6.2
    exceptions-0.10.4 filepath-1.4.2.2
    http-client-tls-0.3.6.3-7PKwybeQpZP3STjfZ1Ty3Q
    http-conduit-2.3.8.3-KkBMXrBtxP6LrN8a2mfNMZ
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    lifted-base-0.2.3.12-LPwBSk7hxRfLQ1PzpNPxYn
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    monad-control-1.0.3.1-I8GZevPHGG9CaaoPHICfGK mtl-2.2.2
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    network-bsd-2.8.1.0-1Y5x0mszWxhBcPjCNBOVSm
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD
    safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    utf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r
    xml-conduit-1.9.1.3-AwLhlaz27ql1567v7tH4L6

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aws-0.24-221.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aws
version:              0.24
visibility:           public
id:                   aws-0.24-DBJcE8rHMknIYEtKtzkNjc
key:                  aws-0.24-DBJcE8rHMknIYEtKtzkNjc
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  d78f7b3298d52fb889ad9f12b026437c
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/aws-0.24
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aws-0.24
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aws-0.24
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aws
hs-libraries:         HSaws-0.24-DBJcE8rHMknIYEtKtzkNjc
depends:
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy
    attoparsec-0.14.4-K9rgVNreKMkFhZdMbsqsTo base-4.17.2.1
    base16-bytestring-1.0.2.0-QNB00R14ilFJ2bl5pXkq5
    base64-bytestring-1.2.1.0-51qKIpJ73TV1AKDjoSOLuj
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS
    byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY bytestring-0.11.5.3
    case-insensitive-1.2.1.0-ADYWB5NR7iSCpUfBs08sXI
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    conduit-1.3.6.1-71bcac4Cc835E6whLI9wK1
    conduit-extra-1.3.6-7CjUmIZxf2RHU2WaCxxouE containers-0.6.7
    cryptonite-0.30-1z5L2om720j2Q27zycLaKL
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-tls-0.3.6.4-LsEMzgIMdlXERrSThNI7aZ
    http-conduit-2.3.9.1-HN8EYrl5M0gKsoAeMqWR8i
    http-types-0.12.4-1mXIbLxCpEKp4Jrjs0euO
    lifted-base-0.2.3.12-4lqeQZi6Is2ElxL17hUAIJ
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    monad-control-1.0.3.1-CU0oSebqH0K53geyhZCKTM mtl-2.2.2
    network-3.1.4.0-AQGzws0tmah75qbsifMDHb
    network-bsd-2.8.1.0-JWhNFQNRCnoDtnJbXnW91o
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    resourcet-1.2.6-1gicgfJmNW9Cb8ffzmTP6H
    safe-0.3.21-9t18UaHoT5jA6SQBJagYvS
    scientific-0.3.7.0-FVWP8DVCKbGBwiSARe0xui
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-WenrpHtwHKIVom5hXYF7C
    utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16
    xml-conduit-1.9.1.4-36Q8Vzw3y3oGpHR6LDDr04

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
